Clazz.declarePackage("J.api");
(function(){
var c$ = Clazz.declareInterface(J.api, "JmolDataManager");
})();
;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
